@@ -94,6 +94,8 @@ public final class SessionHandler {
 
     private static final Log LOG = LogFactory.getLog(SessionHandler.class);
 
+    private static final boolean DEBUG = LOG.isDebugEnabled();
+
     private static ScheduledTimerTask sessiondTimer;
 
     /**
@@ -122,10 +124,11 @@ public final class SessionHandler {
 
             final TimerService timer = SessiondServiceRegistry.getServiceRegistry().getService(TimerService.class);
             if (timer != null) {
-                sessiondTimer = timer.scheduleWithFixedDelay(
-                    new SessiondTimer(),
-                    config.getSessionContainerTimeout(),
-                    config.getSessionContainerTimeout());
+                sessiondTimer =
+                    timer.scheduleWithFixedDelay(
+                        new SessiondTimer(),
+                        config.getSessionContainerTimeout(),
+                        config.getSessionContainerTimeout());
             }
         }
     }
@@ -184,21 +187,15 @@ public final class SessionHandler {
         final String secret = sessionIdGenerator.createSecretId(loginName, String.valueOf(System.currentTimeMillis()));
         final String randomToken = sessionIdGenerator.createRandomId();
 
-        final Session session = new SessionImpl(
-            userId,
-            loginName,
-            password,
-            context.getContextId(),
-            sessionId,
-            secret,
-            randomToken,
-            clientHost,
-            login);
+        final Session session =
+            new SessionImpl(userId, loginName, password, context.getContextId(), sessionId, secret, randomToken, clientHost, login);
 
         LOG.info("Session created. ID: " + sessionId + ", Context: " + context.getContextId() + ", User: " + userId);
 
         sessionData.addSession(session, config.getLifeTime(), noLimit);
 
+        postSessionCreation(session);
+
         return sessionId;
     }
 
@@ -209,7 +206,7 @@ public final class SessionHandler {
      * @return <code>true</code> if a refreshing last-accessed time stamp was successful; otherwise <code>false</code>
      */
     protected static boolean refreshSession(final String sessionid) {
-        if (LOG.isDebugEnabled()) {
+        if (DEBUG) {
             LOG.debug(new StringBuilder("refreshSession <").append(sessionid).append('>').toString());
         }
         return sessionData.getSession(sessionid) != null;
@@ -226,11 +223,10 @@ public final class SessionHandler {
         if (null == sessionControl) {
             LOG.debug("Cannot find session id to remove session <" + sessionid + '>');
             return false;
-        } else {
-            postSessionRemoval(sessionControl.getSession());
-            LOG.info("Session closed. ID: " + sessionid);
-            return true;
         }
+        postSessionRemoval(sessionControl.getSession());
+        LOG.info("Session closed. ID: " + sessionid);
+        return true;
     }
 
     /**
@@ -241,7 +237,7 @@ public final class SessionHandler {
      * @throws SessiondException If changing the password fails
      */
     protected static void changeSessionPassword(final String sessionid, final String newPassword) throws SessiondException {
-        if (LOG.isDebugEnabled()) {
+        if (DEBUG) {
             LOG.debug(new StringBuilder("changeSessionPassword <").append(sessionid).append('>').toString());
         }
         final SessionControl sessionControl = sessionData.getSession(sessionid);
@@ -267,7 +263,7 @@ public final class SessionHandler {
      * @return The session associated with given session ID; otherwise <code>null</code> if expired or none found
      */
     protected static SessionControl getSession(final String sessionid) {
-        if (LOG.isDebugEnabled()) {
+        if (DEBUG) {
             LOG.debug(new StringBuilder("getSession <").append(sessionid).append('>').toString());
         }
         final SessionControl sessionControl = sessionData.getSession(sessionid);
@@ -306,7 +302,7 @@ public final class SessionHandler {
      * @return A wrapping instance of {@link SessionControl} or <code>null</code>
      */
     public static SessionControl getCachedSession(final String secret, final String localIP) {
-        if (LOG.isDebugEnabled()) {
+        if (DEBUG) {
             LOG.debug(new StringBuilder("getCachedSession <").append(secret).append('>').toString());
         }
         try {
@@ -338,14 +334,14 @@ public final class SessionHandler {
      * @return All available instances of {@link SessionControl}
      */
     public static List<SessionControl> getSessions() {
-        if (LOG.isDebugEnabled()) {
+        if (DEBUG) {
             LOG.debug("getSessions");
         }
         return sessionData.getSessions();
     }
 
     protected static void cleanUp() {
-        if (LOG.isDebugEnabled()) {
+        if (DEBUG) {
             LOG.debug("session cleanup");
         }
         final List<SessionControl> sessionControls = sessionData.rotate();
@@ -375,6 +371,19 @@ public final class SessionHandler {
         return sessionData.countSessions();
     }
 
+    private static void postSessionCreation(final Session session) {
+        final EventAdmin eventAdmin = getServiceRegistry().getService(EventAdmin.class);
+        if (eventAdmin != null) {
+            final Dictionary<Object, Object> dic = new Hashtable<Object, Object>();
+            dic.put(SessiondEventConstants.PROP_SESSION, session);
+            final Event event = new Event(SessiondEventConstants.TOPIC_ADD_SESSION, dic);
+            eventAdmin.postEvent(event);
+            if (DEBUG) {
+                LOG.debug("Posted event for added session");
+            }
+        }
+    }
+
     private static void postSessionRemoval(final Session session) {
         final EventAdmin eventAdmin = getServiceRegistry().getService(EventAdmin.class);
         if (eventAdmin != null) {
@@ -382,7 +391,7 @@ public final class SessionHandler {
             dic.put(SessiondEventConstants.PROP_SESSION, session);
             final Event event = new Event(SessiondEventConstants.TOPIC_REMOVE_SESSION, dic);
             eventAdmin.postEvent(event);
-            if (LOG.isDebugEnabled()) {
+            if (DEBUG) {
                 LOG.debug("Posted event for removed session");
             }
         }
@@ -400,7 +409,7 @@ public final class SessionHandler {
             dic.put(SessiondEventConstants.PROP_CONTAINER, eventMap);
             final Event event = new Event(SessiondEventConstants.TOPIC_REMOVE_CONTAINER, dic);
             eventAdmin.postEvent(event);
-            if (LOG.isDebugEnabled()) {
+            if (DEBUG) {
                 LOG.debug("Posted event for removed session container");
             }
         }
